@@ -8,15 +8,15 @@
 
 #include "mailclient_p.h"
 
-#include <KCalendarCore/Incidence>
 #include <KCalendarCore/FreeBusy>
-#include <MailTransportAkonadi/MessageQueueJob>
+#include <KCalendarCore/Incidence>
 #include <KIdentityManagement/Identity>
+#include <MailTransportAkonadi/MessageQueueJob>
 
 #include <qtest_akonadi.h>
 
-#include <QTestEventLoop>
 #include <QObject>
+#include <QTestEventLoop>
 
 static const char *s_ourEmail = "unittests@dev.nul"; // change also in kdepimlibs/akonadi/calendar/tests/unittestenv/kdehome/share/config
 
@@ -63,10 +63,11 @@ public:
     {
     }
 
-    MailTransport::MessageQueueJob *createMessageQueueJob(const KCalendarCore::IncidenceBase::Ptr &incidence, const KIdentityManagement::Identity &identity, QObject *parent = nullptr) override
+    MailTransport::MessageQueueJob *
+    createMessageQueueJob(const KCalendarCore::IncidenceBase::Ptr &incidence, const KIdentityManagement::Identity &identity, QObject *parent = nullptr) override
     {
-        Q_UNUSED(incidence);
-        Q_UNUSED(identity);
+        Q_UNUSED(incidence)
+        Q_UNUSED(identity)
         return new FakeMessageQueueJob(parent);
     }
 };
@@ -90,8 +91,7 @@ private Q_SLOTS:
         mPendingSignals = 0;
         mMailClient = new MailClient(new FakeITIPHandlerComponentFactory(this), this);
         mLastResult = MailClient::ResultSuccess;
-        connect(mMailClient, &MailClient::finished,
-                this, &MailClientTest::handleFinished);
+        connect(mMailClient, &MailClient::finished, this, &MailClientTest::handleFinished);
     }
 
     void cleanupTestCase()
@@ -119,25 +119,23 @@ private Q_SLOTS:
         QString transport;
         MailClient::Result expectedResult = MailClient::ResultNoAttendees;
         const int expectedTransportId = 69372773; // from tests/unittestenv/kdehome/share/config/mailtransports
-        const QString expectedFrom = QStringLiteral("unittests@dev.nul");   // from tests/unittestenv/kdehome/share/config/emailidentities
+        const QString expectedFrom = QStringLiteral("unittests@dev.nul"); // from tests/unittestenv/kdehome/share/config/emailidentities
         KCalendarCore::Person organizer(QStringLiteral("Organizer"), QStringLiteral("unittests@dev.nul"));
 
         QStringList toList;
         QStringList toCcList;
         QStringList toBccList;
         //----------------------------------------------------------------------------------------------
-        QTest::newRow("No attendees") << incidence << identity << bccMe << attachment << transport
-                                      << expectedResult << -1 << QString()
-                                      << toList << toCcList << toBccList;
+        QTest::newRow("No attendees") << incidence << identity << bccMe << attachment << transport << expectedResult << -1 << QString() << toList << toCcList
+                                      << toBccList;
         //----------------------------------------------------------------------------------------------
         // One attendee, but without e-mail
         KCalendarCore::Attendee attendee(QStringLiteral("name1"), QString());
         incidence = KCalendarCore::Incidence::Ptr(new KCalendarCore::Event());
         incidence->addAttendee(attendee);
         expectedResult = MailClient::ResultReallyNoAttendees;
-        QTest::newRow("No attendees with email") << incidence << identity << bccMe << attachment << transport
-                                                 << expectedResult << -1 << QString()
-                                                 << toList << toCcList << toBccList;
+        QTest::newRow("No attendees with email") << incidence << identity << bccMe << attachment << transport << expectedResult << -1 << QString() << toList
+                                                 << toCcList << toBccList;
         //----------------------------------------------------------------------------------------------
         // One valid attendee
         attendee = KCalendarCore::Attendee(QStringLiteral("name1"), QStringLiteral("test@foo.org"));
@@ -146,8 +144,7 @@ private Q_SLOTS:
         incidence->setOrganizer(organizer);
         expectedResult = MailClient::ResultSuccess;
         toList << QStringLiteral("test@foo.org");
-        QTest::newRow("One attendee") << incidence << identity << bccMe << attachment << transport
-                                      << expectedResult << expectedTransportId << expectedFrom
+        QTest::newRow("One attendee") << incidence << identity << bccMe << attachment << transport << expectedResult << expectedTransportId << expectedFrom
                                       << toList << toCcList << toBccList;
         //----------------------------------------------------------------------------------------------
         // One valid attendee
@@ -158,10 +155,8 @@ private Q_SLOTS:
         QString invalidTransport = QStringLiteral("foo");
         expectedResult = MailClient::ResultSuccess;
         // Should default to the default transport
-        QTest::newRow("Invalid transport") << incidence << identity << bccMe << attachment
-                                           << invalidTransport  << expectedResult
-                                           << expectedTransportId << expectedFrom
-                                           << toList << toCcList << toBccList;
+        QTest::newRow("Invalid transport") << incidence << identity << bccMe << attachment << invalidTransport << expectedResult << expectedTransportId
+                                           << expectedFrom << toList << toCcList << toBccList;
         //----------------------------------------------------------------------------------------------
         // One valid attendee, and bcc me
         attendee = KCalendarCore::Attendee(QStringLiteral("name1"), QStringLiteral("test@foo.org"));
@@ -172,9 +167,7 @@ private Q_SLOTS:
         // Should default to the default transport
         toBccList.clear();
         toBccList << QStringLiteral("unittests@dev.nul");
-        QTest::newRow("Test bcc") << incidence << identity << /*bccMe*/ true << attachment
-                                  << transport  << expectedResult
-                                  << expectedTransportId << expectedFrom
+        QTest::newRow("Test bcc") << incidence << identity << /*bccMe*/ true << attachment << transport << expectedResult << expectedTransportId << expectedFrom
                                   << toList << toCcList << toBccList;
         //----------------------------------------------------------------------------------------------
         // Test CC list
@@ -194,11 +187,8 @@ private Q_SLOTS:
         toBccList << QStringLiteral("unittests@dev.nul");
 
         toCcList.clear();
-        toCcList << QStringLiteral("optional@foo.org")
-                 << QStringLiteral("non@foo.org");
-        QTest::newRow("Test cc") << incidence << identity << /*bccMe*/ true << attachment
-                                 << transport  << expectedResult
-                                 << expectedTransportId << expectedFrom
+        toCcList << QStringLiteral("optional@foo.org") << QStringLiteral("non@foo.org");
+        QTest::newRow("Test cc") << incidence << identity << /*bccMe*/ true << attachment << transport << expectedResult << expectedTransportId << expectedFrom
                                  << toList << toCcList << toBccList;
     }
 
@@ -223,8 +213,7 @@ private Q_SLOTS:
         waitForSignals();
 
         if (mLastResult != expectedResult) {
-            qDebug() << "Fail1: last=" << mLastResult << "; expected=" << expectedResult
-                     << "; error=" << mLastErrorMessage;
+            qDebug() << "Fail1: last=" << mLastResult << "; expected=" << expectedResult << "; error=" << mLastErrorMessage;
             QVERIFY(false);
         }
 
@@ -236,8 +225,7 @@ private Q_SLOTS:
         }
 
         if (expectedTransportId != -1 && unitTestResult.transportId != expectedTransportId) {
-            qDebug() << "got " << unitTestResult.transportId
-                     << "; expected=" << expectedTransportId;
+            qDebug() << "got " << unitTestResult.transportId << "; expected=" << expectedTransportId;
             QVERIFY(false);
         }
 
@@ -282,16 +270,14 @@ private Q_SLOTS:
         QString expectedSubject;
         //----------------------------------------------------------------------------------------------
         expectedSubject = subject;
-        QTest::newRow("test1") << incidence << identity << from << bccMe << attachment << subject
-                               << transport << expectedResult << expectedTransportId << expectedFrom
-                               << toList << toBccList << expectedSubject;
+        QTest::newRow("test1") << incidence << identity << from << bccMe << attachment << subject << transport << expectedResult << expectedTransportId
+                               << expectedFrom << toList << toBccList << expectedSubject;
         //----------------------------------------------------------------------------------------------
         expectedSubject = QStringLiteral("Free Busy Message");
         incidence = KCalendarCore::IncidenceBase::Ptr(new KCalendarCore::FreeBusy());
         incidence->setOrganizer(organizer);
-        QTest::newRow("FreeBusy") << incidence << identity << from << bccMe << attachment << subject
-                                  << transport << expectedResult << expectedTransportId << expectedFrom
-                                  << toList << toBccList << expectedSubject;
+        QTest::newRow("FreeBusy") << incidence << identity << from << bccMe << attachment << subject << transport << expectedResult << expectedTransportId
+                                  << expectedFrom << toList << toBccList << expectedSubject;
     }
 
     void testMailOrganizer()
@@ -357,9 +343,8 @@ private Q_SLOTS:
         toList << QLatin1String(s_ourEmail);
         QStringList toBccList;
         //----------------------------------------------------------------------------------------------
-        QTest::newRow("test1") << incidence << identity << from << bccMe << recipients << attachment
-                               << transport << expectedResult << expectedTransportId << expectedFrom
-                               << toList << toBccList;
+        QTest::newRow("test1") << incidence << identity << from << bccMe << recipients << attachment << transport << expectedResult << expectedTransportId
+                               << expectedFrom << toList << toBccList;
     }
 
     void testMailTo()
@@ -404,7 +389,7 @@ private Q_SLOTS:
     void waitForSignals()
     {
         if (mPendingSignals > 0) {
-            QTestEventLoop::instance().enterLoop(5);   // 5 seconds is enough
+            QTestEventLoop::instance().enterLoop(5); // 5 seconds is enough
             QVERIFY(!QTestEventLoop::instance().timeout());
         }
     }
